package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class PMGClass extends Attribute
{
    private int pmgClassIndex;
    private int pmgIndex;
    
    PMGClass(final int nameIndex, final int length, final DataInput input, final ConstantPool constantPool) throws IOException {
        this(nameIndex, length, input.readUnsignedShort(), input.readUnsignedShort(), constantPool);
    }
    
    public PMGClass(final int nameIndex, final int length, final int pmgIndex, final int pmgClassIndex, final ConstantPool constantPool) {
        super((byte)9, nameIndex, length, constantPool);
        this.pmgIndex = pmgIndex;
        this.pmgClassIndex = pmgClassIndex;
    }
    
    public PMGClass(final PMGClass pgmClass) {
        this(pgmClass.getNameIndex(), pgmClass.getLength(), pgmClass.getPMGIndex(), pgmClass.getPMGClassIndex(), pgmClass.getConstantPool());
    }
    
    @Override
    public void accept(final Visitor v) {
        Attribute.println("Visiting non-standard PMGClass object");
    }
    
    @Override
    public Attribute copy(final ConstantPool constantPool) {
        return (Attribute)this.clone();
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.pmgIndex);
        file.writeShort(this.pmgClassIndex);
    }
    
    public int getPMGClassIndex() {
        return this.pmgClassIndex;
    }
    
    public String getPMGClassName() {
        return super.getConstantPool().getConstantUtf8(this.pmgClassIndex).getBytes();
    }
    
    public int getPMGIndex() {
        return this.pmgIndex;
    }
    
    public String getPMGName() {
        return super.getConstantPool().getConstantUtf8(this.pmgIndex).getBytes();
    }
    
    public void setPMGClassIndex(final int pmgClassIndex) {
        this.pmgClassIndex = pmgClassIndex;
    }
    
    public void setPMGIndex(final int pmgIndex) {
        this.pmgIndex = pmgIndex;
    }
    
    @Override
    public String toString() {
        return "PMGClass(" + this.getPMGName() + ", " + this.getPMGClassName() + ")";
    }
}
